<?php

namespace Vinicius\ImageGallery\Providers;

use Illuminate\Support\ServiceProvider;

class ImageGalleryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'image_gallery');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'image_gallery');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('vinicius.image_gallery', function ($app) {
            return $this->app->make('Vinicius\ImageGallery\ImageGallery');
        });

                // Bind Gallery to repository
        $this->app->bind(
            'Vinicius\ImageGallery\Interfaces\GalleryRepositoryInterface',
            \Vinicius\ImageGallery\Repositories\Eloquent\GalleryRepository::class
        );

        $this->app->register(\Vinicius\ImageGallery\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Vinicius\ImageGallery\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['vinicius.image_gallery'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('vinicius/image_gallery.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/image_gallery')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/image_gallery')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
